"""Generated by update_sounds_list.py [2025-08-28 15:45]."""

SOUNDS_LIST = {
    "air_horn_03": "Air horn",
    "amzn_sfx_cat_meow_1x_01": "Cat meow",
    "amzn_sfx_church_bell_1x_02": "Church bell",
    "amzn_sfx_crowd_applause_01": "Crowd applause",
    "amzn_sfx_dog_med_bark_1x_02": "Dog bark",
    "amzn_sfx_doorbell_01": "Doorbell 1",
    "amzn_sfx_doorbell_chime_01": "Doorbell 2",
    "amzn_sfx_doorbell_chime_02": "Doorbell 3",
    "amzn_sfx_large_crowd_cheer_01": "Crowd cheers",
    "amzn_sfx_lion_roar_02": "Lion roar",
    "amzn_sfx_rooster_crow_01": "Rooster",
    "amzn_sfx_scifi_alarm_01": "Sirens",
    "amzn_sfx_scifi_alarm_04": "Red alert",
    "amzn_sfx_scifi_engines_on_02": "Engines on",
    "amzn_sfx_scifi_sheilds_up_01": "Shields up",
    "amzn_sfx_trumpet_bugle_04": "Trumpet",
    "amzn_sfx_wolf_howl_02": "Wolf howl",
    "bell_02": "Bells",
    "boing_01": "Boing 1",
    "boing_03": "Boing 2",
    "buzzers_pistols_01": "Buzzer",
    "camera_01": "Camera",
    "christmas_05": "Christmas bells",
    "clock_01": "Ticking clock",
    "futuristic_10": "Aircraft",
    "halloween_bats": "Halloween bats",
    "halloween_crows": "Halloween crows",
    "halloween_footsteps": "Halloween spooky footsteps",
    "halloween_wind": "Halloween wind",
    "halloween_wolf": "Halloween wolf",
    "holiday_halloween_ghost": "Halloween ghost",
    "horror_10": "Halloween creepy door",
    "med_system_alerts_minimal_dragon_short": "Friendly dragon",
    "med_system_alerts_minimal_owl_short": "Happy owl ",
    "med_system_alerts_minimals_blue_wave_small": "Underwater World Sonata",
    "med_system_alerts_minimals_galaxy_short": "Infinite Galaxy",
    "med_system_alerts_minimals_panda_short": "Baby panda",
    "med_system_alerts_minimals_tiger_short": "Playful tiger",
    "med_ui_success_generic_1-1": "Success 1",
    "squeaky_12": "Squeaky door",
    "zap_01": "Zap",
}



"""GraphQL Queries."""

QUERY_DEVICE_STATE = """
query getDevicesState ($latencyTolerance: LatencyToleranceValue) {
  listEndpoints(listEndpointsInput: { includeHouseholdDevices: true }) {
    endpoints {
      endpointId: id
      friendlyNameObject { value { text } }
      manufacturer { value { text } }
      model { value { text} }
      serialNumber { value { text } }
      softwareVersion { value { text } }
      creationTime
      enablement
      settings {
        doNotDisturb {
          id
          endpointId
          name
          toggleValue
          error {
            type
            message
          }
        }
      }
      displayCategories {
        all { value }
        primary { value }
      }
      alexaEnabledMetadata {
        iconId
        isVisible
        category
        capabilities
      }
      legacyIdentifiers {
        dmsIdentifier {
          deviceType { value { text } }
        }
        chrsIdentifier { entityId }
      }
      legacyAppliance { applianceId }
      associatedUnits { id }
      connections {
          type
          macAddress
          bleMeshDeviceUuid
      }
      features(latencyToleranceValue: $latencyTolerance) {
        name
        instance
        properties {
          name
          type
          accuracy
          error { message }
          __typename
          ... on Illuminance {
            illuminanceValue { value }
            timeOfSample
            timeOfLastChange
          }
          ... on Reachability {
              reachabilityStatusValue
              timeOfSample
              timeOfLastChange
          }
          ... on DetectionState {
              detectionStateValue
              timeOfSample
              timeOfLastChange
          }
          ... on Volume {
              value { volValue: value }
          }
          ... on TemperatureSensor {
              name
              value {
                value
                scale
              }
              timeOfSample
              timeOfLastChange
          }
        }
      }
    }
  }
}
"""
